# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.6.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .old_create_policy import OldCreatePolicy
from .old_partial_update_policy import OldPartialUpdatePolicy
from .old_retrieve_all_policy_types import OldRetrieveAllPolicyTypes
from .old_retrieve_policy_country import OldRetrievePolicyCountry
from .old_retrieve_single_policy import OldRetrieveSinglePolicy
from .retrieve_all_legal_policies import RetrieveAllLegalPolicies
