# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.31.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_subscription_handler import CreateSubscriptionHandler
from .create_topic_handler import CreateTopicHandler
from .delete_topic_handler import DeleteTopicHandler
from .list_topics_handler import ListTopicsHandler
from .unsubscribe_topic_handler import UnsubscribeTopicHandler
