# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.29.3"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_platform_c_b8f2c5 import AdminDeletePlatformCredentials
from .admin_delete_platform_c_78003c import AdminDeletePlatformCredentialsByPlatformId
from .admin_delete_platform_c_78003c import (
    PlatformIdEnum as AdminDeletePlatformCredentialsByPlatformIdPlatformIdEnum,
)
from .admin_get_platform_credentials import AdminGetPlatformCredentials
from .admin_sync_platform_cre_f4389d import AdminSyncPlatformCredentials
from .admin_sync_platform_cre_f4389d import (
    PlatformIdEnum as AdminSyncPlatformCredentialsPlatformIdEnum,
)
from .admin_update_platform_c_5be87f import AdminUpdatePlatformCredentials
from .admin_upload_platform_c_50325d import AdminUploadPlatformCredentials
from .admin_upload_platform_c_50325d import (
    PlatformIdEnum as AdminUploadPlatformCredentialsPlatformIdEnum,
)
